<?php
namespace Concrete\Package\MoceanApiBroadcast;

defined('C5_EXECUTE') or die('Access Denied.');

use Concrete\Core\Asset\AssetList;
use \Concrete\Core\Package\Package;
use \Concrete\Core\Page\Single as SinglePage;
use \Concrete\Core\Database\EntityManager\Provider\ProviderAggregateInterface;
use \Concrete\Core\Database\EntityManager\Provider\StandardPackageProvider;
use Concrete\Core\View\View;

class Controller extends Package implements ProviderAggregateInterface
{
    protected $pkgHandle = 'mocean_api_broadcast';
    protected $appVersionRequired = '8.1.0';
    protected $pkgVersion = '1.0.0';
    protected $pkgAutoloaderRegistries = [
        'src'        => '\Concrete\Package\MoceanApiBroadcast',
        'src/Entity' => '\Concrete\Package\MoceanApiBroadcast\Src\Entity',
        'src/Mocean' => '\Mocean'
    ];

    public function getPackageDescription()
    {
        return t('Allows sending of text messages in bulk to many recipients.');
    }

    public function getPackageName()
    {
        return t('MoceanAPI SMS Broadcast');
    }

    public function getEntityManagerProvider()
    {
        $provider = new StandardPackageProvider($this->app, $this, [
            'src/Entity' => 'Concrete\Package\MoceanApiBroadcast\Src\Entity'
        ]);
        return $provider;
    }

    public function install()
    {
        $pkg = parent::install();
        $page = SinglePage::add('/dashboard/mocean_api_broadcast', $pkg);
        $page->updateCollectionName(t('MoceanAPI SMS Broadcast'));
        SinglePage::add('/dashboard/mocean_api_broadcast/account', $pkg)->update(array('cName' => t('Account Configuration')));
        SinglePage::add('/dashboard/mocean_api_broadcast/send', $pkg)->update(array('cName' => t('SMS Broadcast')));
        SinglePage::add('/dashboard/mocean_api_broadcast/history', $pkg)->update(array('cName' => t('SMS Transaction History')));

        return $pkg;
    }

    public function on_start()
    {
        $al = AssetList::getInstance();
        $al->register(
            'javascript', 'mocean_api_broadcast/cookieconsent', 'assets/js/cookieconsent.min.js', [], "mocean_api_broadcast"
        );
        $al->register(
            'javascript', 'mocean_api_broadcast/yandex', 'assets/js/yandex.js', [], "mocean_api_broadcast"
        );
        $al->register('css', 'mocean_api_broadcast/cookieconsent', 'assets/css/cookieconsent.min.css', [], 'mocean_api_broadcast');
        $al->register('css', 'mocean_api_broadcast/animate', 'assets/css/animate.min.css', [], 'mocean_api_broadcast');
        $al->register('css', 'mocean_api_broadcast/main', 'assets/css/main.css', [], 'mocean_api_broadcast');


    }

}