<?php
namespace Concrete\Package\MoceanApiBroadcast\Src\Entity;

use \Concrete\Core\Search\Pagination\Pagination;
use \Concrete\Core\Search\ItemList\Database\ItemList;
use \Pagerfanta\Adapter\DoctrineDbalAdapter;
use \Doctrine\DBAL\Query\QueryBuilder;
use \Concrete\Core\Support\Facade\DatabaseORM;
use \Concrete\Core\Support\Facade\Application;

class MoceanHistoryList extends ItemList
{
    protected $autoSortColumns = [
        'h.id',
    ];
   
    public function setSearch($search)
    {
        $this->search = $search;
    }

    public function setCustomSearch($custom_search)
    {
        $this->custom_search = $custom_search;
    }

    public function createQuery()
    {
        $this->query->select('h.id')
            ->from('MoceanApiBroadcastHistory', 'h');
    }
    
    public function finalizeQuery(QueryBuilder $query)
    {
        $paramcount = 0;
        $query->orderBy('h.id', 'desc');
        
        if ($this->search) {
            $query->andWhere('h.sender like ?')->setParameter($paramcount++, '%' . $this->search . '%')
                    ->orWhere('h.datetime like ?')->setParameter($paramcount++, '%' . $this->search . '%')
                    ->orWhere('h.message like ?')->setParameter($paramcount++, '%' . $this->search . '%')
                    ->orWhere('h.recipient like ?')->setParameter($paramcount++, '%' . $this->search . '%')
                    ->orWhere('h.response like ?')->setParameter($paramcount++, '%' . $this->search . '%')
                    ->orWhere('h.status like ?')->setParameter($paramcount++, '%' . $this->search . '%');
        }
        elseif (is_array($this->custom_search)) {
            if (!empty($this->custom_search['search'])) {
                $query->andWhere('h.sender like ?')->setParameter($paramcount++, '%' . $this->custom_search['search'] . '%')
                        ->orWhere('h.datetime like ?')->setParameter($paramcount++, '%' . $this->custom_search['search'] . '%')
                        ->orWhere('h.message like ?')->setParameter($paramcount++, '%' . $this->custom_search['search'] . '%')
                        ->orWhere('h.recipient like ?')->setParameter($paramcount++, '%' . $this->custom_search['search'] . '%')
                        ->orWhere('h.response like ?')->setParameter($paramcount++, '%' . $this->custom_search['search'] . '%')
                        ->orWhere('h.status like ?')->setParameter($paramcount++, '%' . $this->custom_search['search'] . '%');
            }
        }
        
        return $query;        
    }
    
    public function getTotalResults()
    {
        $query = $this->deliverQueryObject();
        $query
            ->select('count(distinct h.id)')
            ->setMaxResults(1);
        $result = $query->execute()->fetchColumn();
        return (int) $result;
    }
    
    protected function createPaginationObject()
    {
        $adapter = new DoctrineDbalAdapter(
            $this->deliverQueryObject(),
            function (QueryBuilder $query) {
                $query
                    ->select('count(distinct h.id)')
                    ->setMaxResults(1);
            }
        );
        $pagination = new Pagination($this, $adapter);
        return $pagination;
    }
    
    
    public function getResult($queryRow)
    {
        return MoceanHistory::getByID($queryRow['id']);
    }
}
